A medium-font theme with a white panel background and visible axis lines, suited to conference posters produced via PowerPoint. Removes grid lines.
Usage
hv_theme_poster(
base_size = 16,
base_family = "",
header_family = NULL,
base_line_size = base_size/22,
base_rect_size = base_size/22,
ink = "black",
paper = "white",
accent = "#3366FF"
)
theme_poster(
base_size = 16,
base_family = "",
header_family = NULL,
base_line_size = base_size/22,
base_rect_size = base_size/22,
ink = "black",
paper = "white",
accent = "#3366FF"
)Arguments
- base_size
Base font size in points. Default
16.- base_family
Base font family. Default
""(device default).- header_family
Font family for headers, or
NULLto inheritbase_family. DefaultNULL.- base_line_size
Line size used for axis lines and borders. Default
base_size / 22.- base_rect_size
Rectangle border size. Default
base_size / 22.- ink
Foreground (text and line) colour. Default
"black".- paper
Background colour. Default
"white".- accent
Accent colour used by some
theme_grey()elements. Default"#3366FF".
Value
A ggplot2::theme() object.